@@ -105,7 +105,7 @@ def PlotHydrosphereProps(PlanetList, Params):
             sigCutoff_Sm = 0
         else:
             sigCutoff_Sm = FigMisc.lowSigCutoff_Sm
-        maxSig_Sm = np.max([np.max(Planet.sigma_Sm[:Planet.Steps.nHydro]) for Planet in PlanetList])
+        maxSig_Sm = np.max([np.max(Planet.sigma_Sm[:Planet.Steps.nHydro]) for Planet in PlanetList if not Planet.Do.NO_H2O])
         if maxSig_Sm > sigCutoff_Sm:
             DO_SIGS = True
             vRow += 1
@@ -147,7 +147,6 @@ def PlotHydrosphereProps(PlanetList, Params):
         axsigz.set_xlabel(FigLbl.sigLabel)
         axsigz.set_ylabel(FigLbl.zLabel)
         axsigz.invert_yaxis()
-        axsigz.set_ylim([zMax, 0])
         if FigMisc.LOG_SIG:
             axsigz.set_xscale('log')
         axes.append(axsigz)
@@ -258,8 +257,12 @@ def PlotHydrosphereProps(PlanetList, Params):
 
                 if DO_SIGS:
                     # Plot electrical conductivity vs. depth for hydrosphere
-                    sigma_Sm = Planet.sigma_Sm[indsLiq]
-                    z_km = Planet.z_m[indsLiq]/1e3
+                    if np.size(indsLiq) > 0:
+                        sigma_Sm = Planet.sigma_Sm[indsLiq]
+                        z_km = Planet.z_m[indsLiq]/1e3
+                    else:
+                        sigma_Sm = Planet.sigma_Sm[:Planet.Steps.nHydro]
+                        z_km = Planet.z_m[:Planet.Steps.nHydro]/1e3
                     axsigz.plot(sigma_Sm[sigma_Sm > sigCutoff_Sm], z_km[sigma_Sm > sigCutoff_Sm],
                                 color=thisColor, linewidth=thisLW,
                                 linestyle=Style.LS[Planet.Ocean.comp])
@@ -335,6 +338,12 @@ def PlotHydrosphereProps(PlanetList, Params):
     if Params.LEGEND:
         handles, lbls = axPrho.get_legend_handles_labels()
         axPrho.legend(handles, lbls, loc='lower left')
+
+    if DO_SIGS:
+        axsigz.set_ylim(top=0)
+        if FigMisc.COMMON_ZMAX_SIG:
+            axsigz.set_ylim(bottom=zMax)
+
     plt.tight_layout()
     fig.savefig(Params.FigureFiles.vhydro, format=FigMisc.figFormat, dpi=FigMisc.dpi, metadata=FigLbl.meta)
     log.debug(f'Hydrosphere plot saved to file: {Params.FigureFiles.vhydro}')
